=====
About
=====

treams is developed at the `Karlsruhe Institute of Technology <https://www.kit.edu>`_ by
the
`Institute of Theoretical Solid State Physics <https://www.tfp.kit.edu/rockstuhl.php>`_.

Publications
============

The following publications document the developments and methods for different parts of
the code.

1. `D. Beutel, I. Fernandez-Corbaton, and C. Rockstuhl, Unified Lattice Sums Accommodating Multiple Sublattices for Solutions of the Helmholtz Equation in Two and Three Dimensions, Phys. Rev. A 107, 013508 (2023). <https://doi.org/10.1103/PhysRevA.107.013508>`_
2. `D. Beutel, P. Scott, M. Wegener, C. Rockstuhl, and I. Fernandez-Corbaton, Enhancing the Optical Rotation of Chiral Molecules Using Helicity Preserving All-Dielectric Metasurfaces, Appl. Phys. Lett. 118, 221108 (2021). <https://doi.org/10.1063/5.0050411>`_
3. `D. Beutel, A. Groner, C. Rockstuhl, C. Rockstuhl, and I. Fernandez-Corbaton, Efficient Simulation of Biperiodic, Layered Structures Based on the T-Matrix Method, J. Opt. Soc. Am. B, JOSAB 38, 1782 (2021). <https://doi.org/10.1364/JOSAB.419645>`_
